Declare Function WriteProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any) As Integer
Declare Function GetProfileInt Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Integer) As Integer
Declare Function GetProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Integer) As Integer
Declare Function GetPrivateProfileInt Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As String, ByVal nDefault As Integer, ByVal lpFilename As String) As Integer
Declare Function GetPrivateProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Integer, ByVal lpFilename As String) As Integer
Declare Function WritePrivateProfileString Lib "Kernel" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lplFileName As String) As Integer

Function GetPrivateString (Topic As String, Item As String, RetStr As String) As Integer

'Function Return:
'   -3 = INI_Name not defined or does not exist
'   -2 = No item given to function (Windows API not called)
'   -1 = No topic given to function (Windows API not called)
'  0<= = Length of RetStr returned (Windows API was called)

'RetStr Return:
'    "Default" = API call failed or Topic/Item had no value
'         else = Value of Topic/Item in INI file

RetStr = String$(256, 0)
RetInt% = 0
If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	If (INI_Name = "") Or (Dir$(INI_Name) = "") Then
	    RetInt% = -3
	Else
	    RetInt% = GetPrivateProfileString(Topic, ByVal Item, "Default", RetStr, Len(RetStr), INI_Name)
	    RetStr = Left$(RetStr, RetInt%)
	End If
    End If
End If
GetPrivateString = RetInt%
End Function

Function GetPrivateList (Topic1 As String, List() As String) As Integer

'Function Return:
'   -3 = INI_Name not defined or does not exist
'   -1 = No topic given to function (Windows API not called)
'   0< = Number of Items under the Topic (Windows API was called)

'List() Return:
'    No Change = API call failed or Topic/Item had no value
'         else = Items under the Topic in the INI file

If Topic1 = "" Then
    x = -1
Else
    If (INI_Name = "") Or (Dir$(INI_Name) = "") Then
	x = -3
    Else
	RetList$ = String$(1024, 0)
	top% = UBound(List)
	bottom% = LBound(List)
	x = GetPrivateProfileString(Topic1, ByVal 0&, "default", RetList$, Len(RetList$), INI_Name)
	RetList$ = Left$(RetList$, x)
	x = bottom%
	pos% = InStr(RetList$, Chr$(0))
	prev% = 1
	While (pos%) And (x <= top%)
	    List(x) = Mid$(RetList$, prev%, pos% - prev%)
	    prev% = pos% + 1
	    pos% = InStr(prev%, RetList$, Chr$(0))
	    x = x + 1
	Wend
	While pos% <> 0
	    pos% = InStr(prev%, RetList$, Chr$(0))
	    prev% = pos% + 1
	    x = x + 1
	Wend
    End If
End If
GetPrivateList = x
End Function

Function GetPrivateInt (Topic As String, Item As String, ValueInt As Integer) As Integer

'Function Return:
'   -3 = INI_Name not defined or does not exist
'   -2 = No item given to function (Windows API not called)
'   -1 = No topic given to function (Windows API not called)
'    0 = Windows API was called

'ValueInt Return:
'    0 = Number in INI file is not an integer or is negative
' 9999 = Topic or Item was not found or Item had no value
' Else = The value of Topic and Item in INI file

RetInt% = 0
If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	If (INI_Name = "") Or (Dir$(INI_Name) = "") Then
	    RetInt% = -3
	Else
		ValueInt = GetPrivateProfileInt(Topic, Item, 9999, INI_Name)
	End If
    End If
End If
GetPrivateInt = RetInt%
End Function

Function WritePrivateString (Topic As String, Item As String, WriteStr As String) As Integer

'Return:
'   -3 = INI_Name not defined
'   -1 = No Topic given to function
'   -2 = No Item given to function
'    0 = Write failed
'    1 = Write successful

If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	If INI_Name = "" Then
	   RetInt% = -3
	Else
	    RetInt% = WritePrivateProfileString(Topic, ByVal Item, ByVal WriteStr, INI_Name)
	End If
    End If
End If
WritePrivateString = RetInt%
End Function

Function DelItemPrivate (Topic As String, Item As String) As Integer

'Return:
'   -3 = INI_Name not defined or does not exist
'   -2 = No Item given to function
'   -1 = No Topic given to function
'    0 = Delete failed
'    1 = Delete successful

If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	If (INI_Name = "") Or (Dir$(INI_Name) = "") Then
	   RetInt% = -3
	Else
	    RetInt% = WritePrivateProfileString(Topic, ByVal Item, ByVal 0&, INI_Name)
	End If
    End If
End If
DelItemPrivate = RetInt%
End Function

Function DelTopicPrivate (Topic As String) As Integer
'Return:
'   -3 = INI_Name not defined or does not exist
'   -1 = No Topic given to function
'    0 = Delete failed
'    1 = Delete successful

If Topic = "" Then
    RetInt% = -1
Else
    If (INI_Name = "") Or (Dir$(INI_Name) = "") Then
	RetInt% = -3
    Else
	RetInt% = WritePrivateProfileString(Topic, ByVal 0&, ByVal 0&, INI_Name)
    End If
End If
DelTopicPrivate = RetInt%
End Function

Function GetWinString (Topic As String, Item As String, RetStr As String) As Integer

'Function Return:
'   -2 = No item given to function (Windows API not called)
'   -1 = No topic given to function (Windows API not called)
'  0<= = Length of RetStr returned (Windows API was called)

'RetStr Return:
'    "Default" = API call failed or Topic/Item had no value
'         else = Value of Topic/Item in INI file

RetStr = String$(256, 0)
RetInt% = 0
If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	RetInt% = GetProfileString(Topic, ByVal Item, "Default", RetStr, Len(RetStr))
	RetStr = Left$(RetStr, RetInt%)
    End If
End If
GetWinString = RetInt%
End Function

Function GetWinList (Topic1 As String, List() As String) As Integer

'Function Return:
'   -1 = No topic given to function (Windows API not called)
'   0< = Number of Items under the Topic (Windows API was called)

'List() Return:
'    No Change = API call failed or Topic/Item had no value
'         else = Items under the Topic in the INI file

If Topic1 = "" Then
    x = -1
Else
    RetList$ = String$(1024, 0)
    top% = UBound(List)
    bottom% = LBound(List)
    x = GetProfileString(Topic1, ByVal 0&, "default", RetList$, Len(RetList$))
    RetList$ = Left$(RetList$, x)
    x = bottom%
    pos% = InStr(RetList$, Chr$(0))
    prev% = 1
    While (pos%) And (x <= top%)
	List(x) = Mid$(RetList$, prev%, pos% - prev%)
	prev% = pos% + 1
	pos% = InStr(prev%, RetList$, Chr$(0))
	x = x + 1
    Wend
    While pos% <> 0
	pos% = InStr(prev%, RetList$, Chr$(0))
	prev% = pos% + 1
	x = x + 1
    Wend
End If
GetWinList = x
End Function

Function GetWinInt (Topic As String, Item As String, ValueInt As Integer) As Integer

'Function Return:
'   -2 = No item given to function (Windows API not called)
'   -1 = No topic given to function (Windows API not called)
'    0 = Windows API was called

'ValueInt Return:
'    0 = Number in INI file is not an integer or is negative
' 9999 = Topic or Item was not found or Item had no value
' Else = The value of Topic and Item in INI file

RetInt% = 0
If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	ValueInt = GetProfileInt(Topic, Item, 9999)
    End If
End If
GetWinInt = RetInt%
End Function

Function WriteWinString (Topic As String, Item As String, WriteStr As String) As Integer

'Return:
'   -1 = No Topic given to function
'   -2 = No Item given to function
'    0 = Write failed
'    1 = Write successful

If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	RetInt% = WriteProfileString(Topic, ByVal Item, ByVal WriteStr)
    End If
End If
WriteWinString = RetInt%
End Function

Function DelItemWin (Topic As String, Item As String) As Integer

'Return:
'   -1 = No Topic given to function
'   -2 = No Item given to function
'    0 = Delete failed
'    1 = Delete successful

If Topic = "" Then
    RetInt% = -1
Else
    If Item = "" Then
	RetInt% = -2
    Else
	RetInt% = WriteProfileString(Topic, ByVal Item, ByVal 0&)
    End If
End If
DelItemWin = RetInt%
End Function

Function DelTopicWin (Topic As String) As Integer
'Return:
'   -1 = No Topic given to function
'    0 = Delete failed
'    1 = Delete successful

If Topic = "" Then
    RetInt% = -1
Else
    RetInt% = WriteProfileString(Topic, ByVal 0&, ByVal 0&)
End If
DelTopicWin = RetInt%
End Function

